This package includes functions for the design and analysis of stepped wedge cluster randomized trials according to a repeated cross-sectional sampling scheme. For additional guidance, see (Voldal EC, Hakhu NR, Xia F, Heagerty PJ, Hughes JP. swCRTdesign: An R package for stepped wedge trial design and analysis. Computer Methods and Programs in Biomedicine 2020;196:105514. <doi:10.1016/j.cmpb.2020.105514>). Five primary functions - swPwr, swPwrGlm, swSim, swSummary, and swPlot - and two support functions - blkDiag, swDsn - are included. The blkDiag function creates a block diagonal matrix from a specified array or list of block-matrices. The swDsn function creates a stepped wedge (SW) design object based on specified information on clusters, time points, and the two arms of the cluster randomized trial (CRT). The swPwr function computes the (two-sided) power of treatment effect (\(\theta\)) for the specified SW CRT design via weighted least squares (WLS), where the response/outcome of interest is assumed to come from a mixed effects model with linear link and random time effects and (possibly correlated) random intercepts and random treatment effects. The random time effects apply to all time points, and time is treated as categorical. swPwrGlm does power calculations using the generalized linear model framework (Xia et al, 2019). swPwr and swPwrGlm provide power calculations for both an immediate treatment (IT) model and an exposure time indicator (ETI) model (Kenny et al, 2022). The swSim function generates individual-level data consisting of response, treatment, time, and cluster variables based on a specified SW CRT design. The swSummary function computes the mean, sum, or number of non-missing response values for clusters separately or aggregated by wave at each time point from stepped wedge data that includes, at least, response, treatment, time, and cluster variables. The swPlot function plots mean response as a combined or separate plot, for waves and clusters. Some features of the package are also available as a shiny app, available online (https://swcrtdesign.shinyapps.io/stepped_wedge_power_calculation/) or to download and run locally (https://github.com/swCRTdesign/Stepped-wedge-power-calculation).
James P Hughes, Navneet R Hakhu, Emily C Voldal, and Fan Xia
Maintainer: James P Hughes <jphughes@uw.edu>
| Package: | swCRTdesign |
| Type: | Package |
| Version: | 3.3 |
| Date: | 2022-07-7 |
| License: | GPL (>= 2) |
Hussey MA, Hughes JP. Design and analysis of stepped wedge cluster randomized trials. Contemporary Clinical Trials 2007;28:182-191.
Kenny A, Voldal E, Xia F, Heagerty PJ, Hughes JP. Analysis of stepped wedge cluster randomized trials in the presence of a time-varying treatment effect. Statistics in Medicine, in press, 2022.
Voldal EC, Hakhu NR, Xia F, Heagerty PJ, Hughes JP. swCRTdesign: An R package for stepped wedge trial design and analysis. Computer Methods and Programs in Biomedicine 2020;196:105514.
Xia F, Hughes JP, Voldal EC, Heagerty PJ. Power and sample size calculation for stepped-wedge designs with discrete outcomes. Trials. 2021 Dec;22(1):598.